cmd

package
v0.0.0-...-8848863 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CLI

type CLI struct {
	// contains filtered or unexported fields
}

CLI represents the command line interface component.

func New

func New(p *NewParams) *CLI

New returns a pointer to the `CLI` struct.

func (*CLI) Run

func (c *CLI) Run(p *RunParams) (*RunResult, error)

Run runs the CLI application and returns the result.

func (*CLI) UpdateModel

func (c *CLI) UpdateModel(model bubbletea.Model) error

`UpdateModel` calls the `BubbleTea` component `UpdateModel` method.

type NewParams

type NewParams struct {
	// Bubbletea is the component parameter that wraps the bubbletea library.
	Bubbletea *bubbletea.BubbleTea
}

NewParams represents the parameters for the new method.

type RunParams

type RunParams struct {
	// `ResultCallback` is the results callback Run parameter.
	ResultCallback func(result *bubbletea.BubbleTeaResult) error
}

RunParams are the parameters of the run method.

type RunResult

type RunResult struct {
	// `ChoicesModelResult` is the result of the `ChoicesModel`.
	ChoicesModelResult *bubbletea.ChoicesModelResult

	// `TableModelResult` is the result of the `TableModel`.
	TableModelResult *bubbletea.TableModelResult
}

RunResult is the result of executing the run method.

Directories

Path Synopsis
internal
multiple command
single command

Jump to