puller

package
v0.0.0-...-8848863 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PullParams

type PullParams struct {
	// Specification is the code repository of the graphql specification.
	Specification *types.Repository

	// Implementation is the code repository of the graphql implementation.
	Implementation *types.Repository
}

PullParams represents the parameters of the pull method.

type PullResult

type PullResult struct {
}

PullResult represents the result of the pull method.

type Puller

type Puller struct {
}

Puller represents the puller component.

func New

func New() *Puller

New returns a pointer to a Puller struct.

func (*Puller) Pull

func (p *Puller) Pull(params *PullParams) (*PullResult, error)

Pull pulls a set of code repositories and returns the result.

Jump to