Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CLI ¶
type CLI struct {
// contains filtered or unexported fields
}
CLI represents the command line interface component.
type NewParams ¶
type NewParams struct {
// Bubbletea is the component parameter that wraps the bubbletea library.
Bubbletea *bubbletea.BubbleTea
}
NewParams represents the parameters for the new method.
type RunParams ¶
type RunParams struct {
// `ResultCallback` is the results callback Run parameter.
ResultCallback func(result *bubbletea.BubbleTeaResult) error
}
RunParams are the parameters of the run method.
type RunResult ¶
type RunResult struct {
// `ChoicesModelResult` is the result of the `ChoicesModel`.
ChoicesModelResult *bubbletea.ChoicesModelResult
// `TableModelResult` is the result of the `TableModel`.
TableModelResult *bubbletea.TableModelResult
}
RunResult is the result of executing the run method.
Click to show internal directories.
Click to hide internal directories.