Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PullParams ¶
type PullParams struct {
// Specification is the code repository of the graphql specification.
Specification *types.Repository
// Implementation is the code repository of the graphql implementation.
Implementation *types.Repository
}
PullParams represents the parameters of the pull method.
Click to show internal directories.
Click to hide internal directories.